# Велес
мініфреймворк для простих застосунків на основі таких компонентів як контролер, сервіс, відображення, репозиторій
## встановлення і документація
https://pypi.org/project/veles-vh/
https://test.pypi.org/project/veles-vh/0.1.0/
## оновлення пакета
```shell
python -m build
python -m twine upload --repository pypi dist/*
```
